==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/ms/v20180408/models/ScanPermissionList.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ms.v20180408.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ScanPermissionList  extends AbstractModel{

    /**
    * 系统权限信息
    */
    @SerializedName("PermissionList")
    @Expose
    private ScanPermissionInfo [] PermissionList;

    /**
     * 获取系统权限信息
     * @return PermissionList 系统权限信息
     */
    public ScanPermissionInfo [] getPermissionList() {
        return this.PermissionList;
    }

    /**
     * 设置系统权限信息
     * @param PermissionList 系统权限信息
     */
    public void setPermissionList(ScanPermissionInfo [] PermissionList) {
        this.PermissionList = PermissionList;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "PermissionList.", this.PermissionList);

    }
}

==> tencentcloud-sdk-java-3.1.97-sources.jar: com/tencentcloudapi/ms/v20180408/models/ScanPermissionList.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ms.v20180408.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ScanPermissionList extends AbstractModel{

    /**
    * 系统权限信息
    */
    @SerializedName("PermissionList")
    @Expose
    private ScanPermissionInfo [] PermissionList;

    /**
     * Get 系统权限信息 
     * @return PermissionList 系统权限信息
     */
    public ScanPermissionInfo [] getPermissionList() {
        return this.PermissionList;
    }

    /**
     * Set 系统权限信息
     * @param PermissionList 系统权限信息
     */
    public void setPermissionList(ScanPermissionInfo [] PermissionList) {
        this.PermissionList = PermissionList;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "PermissionList.", this.PermissionList);

    }
}
